'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.sophisticateHTML = sophisticateHTML;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _ejs = require('ejs');

var _ejs2 = _interopRequireDefault(_ejs);

var _inlineSvg = require('./inline-svg');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// ----------------------------------------------------------------------------
// Public
// ----------------------------------------------------------------------------

/**
 * sophisticateHTML - Sophisticate the SVG files and generate the containing
 *                    HTML file from the template.
 *
 * @param {object} argv parsed command line arguments.
 */
function sophisticateHTML(argv) {
  console.log('Generating HTML files…');

  if (argv.s) {
    var fileName = typeof argv.s === "string" ? argv.s : 'inlined-all';
    var processes = [];

    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
      var _loop = function _loop() {
        var path = _step.value;

        processes.push(new Promise(function (resolve, reject) {
          (0, _inlineSvg.processSVG)(path, argv.c, function (result) {
            resolve(result.data);
          });
        }));
      };

      for (var _iterator = argv._[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
        _loop();
      }
    } catch (err) {
      _didIteratorError = true;
      _iteratorError = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion && _iterator.return) {
          _iterator.return();
        }
      } finally {
        if (_didIteratorError) {
          throw _iteratorError;
        }
      }
    }

    Promise.all(processes).then(function (data) {
      writeHTML(argv, fileName, data);
    });
  } else {
    var _iteratorNormalCompletion2 = true;
    var _didIteratorError2 = false;
    var _iteratorError2 = undefined;

    try {
      var _loop2 = function _loop2() {
        var path = _step2.value;

        (0, _inlineSvg.processSVG)(path, argv.c, function (result) {
          writeHTML(argv, path, result.data);
        });
      };

      for (var _iterator2 = argv._[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
        _loop2();
      }
    } catch (err) {
      _didIteratorError2 = true;
      _iteratorError2 = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion2 && _iterator2.return) {
          _iterator2.return();
        }
      } finally {
        if (_didIteratorError2) {
          throw _iteratorError2;
        }
      }
    }
  }
}

/**
 * writeHTML - Sophisticate the SVG files and generate the containing
 *                    HTML file from the template.
 *
 * @param {object} argv parsed command line arguments.
 * @param {string} path path to the original SVG file OR basename of the HTML file to write.
 * @param {object|string} svg svg object to write into the HTML template.
 */
/**
 * @fileoverview Sophisticate the SVG files and generate the containing HTML file from the template.
 * @author Frédéric Maquin <fred@ephread.com>
 */

// ----------------------------------------------------------------------------
// Requirements
// ----------------------------------------------------------------------------

function writeHTML(argv, path, svg) {
  var filename = argv.o + '/' + _path2.default.basename(path).replace(/\.[^/.]+$/, '') + '.html';

  _ejs2.default.renderFile(argv.t, { svg: svg }, function (err, str) {
    if (err) {
      console.log('[' + _chalk2.default.red('ERROR') + '] Couldn\'t render HTML file - ' + err.message);
      process.exit(1);
    }

    _fs2.default.writeFile(filename, str, function (fsErr) {
      if (fsErr) {
        console.log('[' + _chalk2.default.red('ERROR') + '] Couldn\'t write HTML file - ' + fsErr.message);
        process.exit(1);
      } else {
        console.log(_chalk2.default.green('DONE!') + ' - Output: ' + filename);
      }
    });
  });
}