'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.match = match;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _jsYaml = require('js-yaml');

var _jsYaml2 = _interopRequireDefault(_jsYaml);

var _libxmljs = require('libxmljs');

var _libxmljs2 = _interopRequireDefault(_libxmljs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// ----------------------------------------------------------------------------
// Public
// ----------------------------------------------------------------------------

/**
 * match - Show element matching XPath described in the configuration file.
 *
 * @param {type} argv parsed command line arguments.
 */
/**
 * @fileoverview Sophisticate the SVG files.
 * @author Frédéric Maquin <fred@ephread.com>
 */

// ----------------------------------------------------------------------------
// Requirements
// ----------------------------------------------------------------------------

function match(argv) {
  _fs2.default.readFile(argv._[0], 'utf-8', function (err, data) {
    if (err) {
      console.log('[' + _chalk2.default.red('ERROR') + '] Couldn\'t read SVG file - ' + err.message);
      process.exit(1);
    }

    console.log(_chalk2.default.bold('\nMatches for each XPath in the config file:\n'));

    var namespace = 'http://www.w3.org/2000/svg';
    var config = loadConfig(argv.c);
    var xml = _libxmljs2.default.parseXml(data);

    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
      for (var _iterator = config.sophisticate[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
        var transformation = _step.value;

        var xpath = transformation.xpath;

        var nodes = xml.find(xpath, namespace).map(function (element) {
          var substitute = element.clone();

          var pathAttribute = substitute.attr('d');
          var styleAttribute = substitute.attr('style');

          if (pathAttribute) {
            pathAttribute.remove();
          }
          if (styleAttribute) {
            styleAttribute.remove();
          }

          return '    [' + _chalk2.default.blue('LINE ' + substitute.line()) + '] - ' + substitute.toString();
        });

        var section = _chalk2.default.bold('[XPATH]') + ' ' + _chalk2.default.underline.green(xpath) + ' ' + _chalk2.default.bold('matches') + ':';

        console.log(section + '\n' + nodes.join('\n') + '\n');
      }
    } catch (err) {
      _didIteratorError = true;
      _iteratorError = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion && _iterator.return) {
          _iterator.return();
        }
      } finally {
        if (_didIteratorError) {
          throw _iteratorError;
        }
      }
    }
  });
}

/**
 * loadConfig - load the configuration file
 *
 * @param  {string} configPath the path to the configuration file
 * @return {object}            the loaded configuration
 */
function loadConfig(configPath) {
  try {
    return _jsYaml2.default.safeLoad(_fs2.default.readFileSync(configPath, 'utf8'));
  } catch (err) {
    console.log('[' + _chalk2.default.red('ERROR') + '] Couldn\'t load config file - ' + err.message);
    process.exit(1);
  }
}