"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.addAttribute = addAttribute;
/**
 * @fileoverview Add an attribute
 * @author Frédéric Maquin <fred@ephread.com>
 */

// ----------------------------------------------------------------------------
// Public
// ----------------------------------------------------------------------------

/**
 * addAttribute - Add an attribute specified by the given rule to the given nodes.
 *
 * @param {object} rule  rule definition
 * @param {object} nodes nodes on which remove attributes
 */
function addAttribute(rule, nodes) {
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    var _loop = function _loop() {
      var attribute = _step.value;

      var attributeName = Object.keys(attribute)[0];
      var value = attribute[attributeName];

      if (rule.append) {
        nodes.forEach(function (path) {
          var currentValue = path.attr(attributeName);
          var valueToSet = value;

          if (currentValue != null) {
            valueToSet = currentValue.value() + " " + valueToSet;
          }

          path.attr(attributeName, valueToSet);
        });
      } else {
        nodes.forEach(function (path) {
          return path.attr(attributeName, value);
        });
      }
    };

    for (var _iterator = rule.attributes[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      _loop();
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }
}