"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.copyAttribute = copyAttribute;
/**
 * @fileoverview Copy an attribute
 * @author Frédéric Maquin <fred@ephread.com>
 */

// ----------------------------------------------------------------------------
// Public
// ----------------------------------------------------------------------------

/**
 * copyAttribute - Copy the value of an attribute to a new attribute, specified by the
 *                 given rule to the given nodes.
 *
 * @param {object} rule  rule definition
 * @param {object} nodes nodes on which copy the attribute
 */
function copyAttribute(rule, nodes) {
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    var _loop = function _loop() {
      var attribute = _step.value;

      var oldAttributeName = Object.keys(attribute)[0];
      var newAttributeName = attribute[oldAttributeName];

      nodes.forEach(function (node) {
        node.attr(newAttributeName, node.attr(oldAttributeName).value());
      });
    };

    for (var _iterator = rule.attributes[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      _loop();
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }
}