"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.deleteAttribute = deleteAttribute;
/**
 * @fileoverview Delete an attribute
 * @author Frédéric Maquin <fred@ephread.com>
 */

// ----------------------------------------------------------------------------
// Public
// ----------------------------------------------------------------------------

/**
 * deleteAttribute - Delete an attribute specified by the given rule to the given nodes.
 *
 * @param {object} rule  rule definition
 * @param {object} nodes nodes on which remove attributes
 */
function deleteAttribute(rule, nodes) {
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    var _loop = function _loop() {
      var attributeName = _step.value;

      nodes.forEach(function (node) {
        var attribute = node.attr(attributeName);

        if (attribute) {
          attribute.remove();
        }
      });
    };

    for (var _iterator = rule.attributes[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      _loop();
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }
}